#
# spec file for package libphonenumber
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_ver 8
%define lib_ver2 8.13
Name:           libphonenumber
Version:        8.13.40
Release:        1.4
Summary:        Library for parsing, formatting, and validating international phone numbers
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/google/libphonenumber
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-DOWNSTREAM (see https://github.com/google/libphonenumber/pull/2874)
Patch2:         0001-Revert-Fix-typo-in-arguments-to-add_metadata_gen_tar.patch
Patch3:         0001-Add-support-to-protobuf-3.25.1.patch
Patch4:         0002-Avoid-intermediate-proto-object-library.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libboost_date_time-devel >= 1.40.0
BuildRequires:  libboost_system-devel >= 1.40.0
BuildRequires:  libboost_thread-devel >= 1.40.0
BuildRequires:  pkgconfig
# Actual version requirement unknown
BuildRequires:  cmake(absl)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(icu-i18n) >= 4.4
BuildRequires:  pkgconfig(icu-uc) >= 4.4
BuildRequires:  pkgconfig(protobuf) >= 2.4

%description
Google's common Java, C++ and JavaScript library for parsing, formatting,
and validating international phone numbers.

%package     -n %{name}%{lib_ver}
Summary:        Library for parsing, formatting, and validating international phone numbers
Group:          System/Libraries

%description -n %{name}%{lib_ver}
Google's common Java, C++ and JavaScript library for parsing, formatting,
and validating international phone numbers. The Java version is optimized
for running on smartphones, and is used by the Android framework since 4.0
(Ice Cream Sandwich).

%package        devel
Summary:        Library for parsing, formatting, and validating international phone numbers
Group:          Development/Libraries/C and C++
Requires:       %{name}%{lib_ver} = %{version}
Requires:       cmake(absl)
Requires:       pkgconfig(protobuf) >= 2.4

%description    devel
Google's common Java, C++ and JavaScript library for parsing, formatting,
and validating international phone numbers. The Java version is optimized
for running on smartphones, and is used by the Android framework since 4.0
(Ice Cream Sandwich).

This package provides libraries and header files for developing applications
that use libphonenumber.

%prep
%autosetup -p1

%build
cd cpp
# Enabling the geocoder breaks quite a lot due to broken cmakelists
# (https://github.com/google/libphonenumber/pull/2556)
%cmake -DBUILD_STATIC_LIB=OFF -DBUILD_SHARED_LIB=ON -DBUILD_TESTING=ON -DBUILD_GEOCODER=OFF -DREGENERATE_METADATA=OFF
%make_jobs

%install
cd cpp
%cmake_install

%check
cd cpp/build
%make_jobs tests

%post -n %{name}%{lib_ver} -p /sbin/ldconfig
%postun -n %{name}%{lib_ver} -p /sbin/ldconfig

%files -n %{name}%{lib_ver}
%license LICENSE*
%{_libdir}/libphonenumber.so.%{lib_ver}
%{_libdir}/libphonenumber.so.%{lib_ver2}

%files devel
%{_libdir}/libphonenumber.so
%{_includedir}/phonenumbers/
%dir %{_libdir}/cmake/
%{_libdir}/cmake/libphonenumber/

%changelog
* Fri Jul  5 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 8.13.40:
  * Updated metadata
- Use mode="manual" in _service
* Thu Feb 22 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 8.13.30:
  * Update alternate formatting data, phone metadata, geocoding
    data, carrier data
  * Updated / refreshed time zone meta data.
  * New geocoding data
- Add patch submitted to upstream at gh#google/libphonenumber#3394
  to fix building with protobuf 3.25.1:
  * 0001-Add-support-to-protobuf-3.25.1.patch
- Add patch submitted in gh#sergiomb2/libphonenumber#1 by
  Fabian Vogt:
  * 0002-Avoid-intermediate-proto-object-library.patch
* Sun Oct 22 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.13.23:
  * Updated phone metadata, carrier data, geocoding data, short
    number metadata for a number of region and calling codes
- drop 0001-Build-with-C-17.patch now upstream
* Mon Jun 26 2023 Fabian Vogt <fvogt@suse.com>
- absl is also needed for using the -devel package
* Fri Jun 23 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 8.13.15:
  * Updated phone metadata for region code(s): BE, BF, IL, MN, NE, OM, SO, SV
  * Updated carrier data for country calling code(s):
    226 (en), 227 (en), 252 (en), 351 (en), 968 (en), 972 (en)
* Wed Jun 14 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 8.13.14:
  * Many data changes
  * Removal of unused leading_zero_possible proto field in
    phonemetadata.proto and all generated code
  * https://github.com/google/libphonenumber/blob/v8.13.14/release_notes.txt
- Depends on abseil now
- Turn metadata regeneration off explicitly, wasn't done previously
  either. This allows dropping the java dependency.
- Add patches to fix building:
  * 0001-Build-with-C-17.patch
  * 0001-Revert-Fix-typo-in-arguments-to-add_metadata_gen_tar.patch
- protobuf got fixed, builds fine with 22 now
* Tue Jun 13 2023 Dirk Müller <dmueller@suse.com>
- prefer protobuf 21 as it is not compatible with v22
* Thu May 20 2021 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.12.23:
  * Updated phone metadata for region code(s): BF, CI, RW, SG, UG, US, UZ
  * Updated short number metadata for region code(s): DZ
  * New geocoding data for country calling code(s): 1572 (en)
  * Updated geocoding data for country calling code(s): 225 (en)
  * Updated carrier data for country calling code(s):
    65 (en), 225 (en), 226 (en), 250 (en), 256 (en), 998 (en)
  * Updated / refreshed time zone meta data
* Thu May  6 2021 Fabian Vogt <fvogt@suse.com>
- Update to v8.12.22:
  * See https://github.com/google/libphonenumber/blob/v8.12.22/release_notes.txt
* Tue Sep 22 2020 Fabian Vogt <fvogt@suse.com>
- Update to v8.12.10:
  * See https://github.com/google/libphonenumber/blob/v8.12.10/release_notes.txt
- The upstream repo and tarball include binary .jar archives with legally
  questionable content. Switch to a _service and exclude those.
* Sat Sep 19 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v8.12.9
  * see https://github.com/google/libphonenumber/blob/v8.12.9/release_notes.txt
* Wed Jul 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit for v8.10.15
